# Released under copyright CC0
# Author: Poisot, Timoth?e <tim@poisotlab.io>
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
# the Software, and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

setwd("~/Desktop/New-matrix/bri/")

# Packages
library(plyr)
library(ggplot2)
#library(lpbrim)
library(vegan)
library(bipartite)


# Locate the files and read the matrices
matrices_files <- list.files(".", pattern="csv", recursive=T) #### this looks into dir and see file names. pattern only picks CSV
matrices <- alply(matrices_files,
                  1,
                  read.csv, h=T, row.names=1) ##### seems to actually read the files that match the file names 


# Name the matrices
matrices_names <- laply(strsplit(matrices_files, "/"),
                        paste, collapse="-") #### removes the / replaces with a dash
matrices_names <- laply(strsplit(matrices_names, "  "),
                        paste, collapse="") #### cant see diff but likly removes double spaces
matrices_names <- laply(strsplit(matrices_names, "\\."),
                        function (x) x[1]) #### preps file by removing the .CSV from end of string

names(matrices) <- matrices_names #### gives names from last command to the matrices, before they were just numbered 1-18 now they have the name giving from file name


# Clean the matrices -- anything below 0 is removed
clean_matrix <- function(x) {
  x[is.na(x)] <- 0
  x[x<0] <- 0
  return(x[rowSums(x)>0, colSums(x)>0])
}

matrices <- llply(matrices, data.matrix)
matrices <- llply(matrices, clean_matrix)
MAX_VAL <- max(laply(matrices, max))
matrices <- llply(matrices, function(x) x / MAX_VAL)

#######################################################
####function to calculate mean and standard error:#####
#######################################################
data_summary <- function(data, varname, groupnames){
  require(plyr)
  summary_func <- function(x, col){
    c(mean = mean(x[[col]], na.rm=TRUE),
      sd = sd(x[[col]], na.rm=TRUE), se = sd(x[[col]], na.rm=TRUE)/length(x[[col]]), max = max(x[[col]], na.rm = FALSE),
      min = min(x[[col]], na.rm = FALSE))
  }
  data_sum<-ddply(data, groupnames, .fun=summary_func,
                  varname)
  data_sum <- rename(data_sum, c("mean" = varname))
  return(data_sum)
}
##################################################################


# Matrix analysis functions

pielou <- function(x) {
  # Pielou (whole matrix)
  p <- x[x>0]
  p <- p/sum(p)
  n <- length(p)
  H <- -sum(p * log(p))
  Hmax <- log(n)
  return(H/Hmax)
}

co_q <- function(x) {
  # Mean interaction strength
  return(sum(x)/prod(dim(x)))
} 
co_q_plus <- function(x) {
  # Mean interaction strength (only + interactions)
  return(mean(x[x>0]))
}

co_b <- function(x) {
  # Connectance
  y <- x
  y[x>0] <- 1
  return(co_q(y))
}

Q <- function(x) {
  # Modularity
  return(
    lpbrim::findModules(x, sparse=F)$Q   ########THIS IS THE OLD FUNCTION USED BY TIM
    
  )
}

NODF <- function(x) {
  # Nestedness
  return(
    as.numeric(nestednodf(x)$statistic[3]/100)
  )
}

modularity2 <- function(x) {
  # Nestedness
  lad <-computeModules(x, deep = FALSE, deleteOriginalFiles = TRUE,
                       steps = 100000, tolerance = 1e-10, experimental = FALSE)
  return(lad@likelihood  #### THIS IS THE MODULARITY FUNCTION I AM USING
         
  )
}

# Aggregate results
results <- ldply(matrices,
                 function(x) {
                   c(
                     entropy=pielou(x),
                     connectance=co_b(x),
                     linkstrength=co_q(x),
                     linkstrength_2=co_q_plus(x),
                     # modularity=Q(x),
                     nestedness=NODF(x)
                     ,modularity=modularity2(x)
                   )
                 })




results$time <- as.numeric(substr(results$`.id`, 2, 2))
results$strain <- substr(results$`.id`, 6, 7)
results$replicate <- substr(results$`.id`, 9, 9)
results$strain[results$strain == "14"] <- "14/1"
results$strain[results$strain == "LU"] <- "LUZ19"
results$strain = as.factor(results$strain)

write.table(results,
            "results.csv",
            sep=",",
            col.names=T,
            quote=F,
            row.names=F)

#functions for ggplots



#function to draw linear fit model with stat summary:
ggplotRegression <- function (fit) {
  
  require(ggplot2)
  
  ggplot(fit$model, aes_string(x = names(fit$model)[2], y = names(fit$model)[1])) + 
    geom_point() +
    stat_smooth(method = "lm", col = "red") +
    labs(title = paste( summary(fit)$call[[3]] ,"Adj R2 = ",signif(summary(fit)$adj.r.squared, 5),
                        "Intercept =",signif(fit$coef[[1]],5 ),
                        " Slope =",signif(fit$coef[[2]], 5),
                        " P =",signif(summary(fit)$coef[2,4], 5)))
}



nestedness <- data_summary(results, varname="nestedness", 
                           groupnames="time")
modularity <- data_summary(results, varname="modularity", 
                           groupnames="time")
modularity_LP <- data_summary(results, varname="modd", 
                              groupnames="time")
summary(results)

#plotting nestedness and modularity with time:
p<- ggplot(nestedness, aes(x=time, y=nestedness)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=nestedness-sd, ymax=nestedness+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="Nestedness vs. Time", x="Time Point", y = "Nestedness")+geom_smooth(method = "lm", se = FALSE)

p<- ggplot(modularity, aes(x=time, y=modularity)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=modularity-sd, ymax=modularity+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="Modularity vs. Time", x="Time Point", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)

p<- ggplot(modularity_LP, aes(x=time, y=modd)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=modd-sd, ymax=modd+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="Modularity vs. Time", x="Time Point", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)


#testing difference in nestedness between two phages across time
myData <- cbind(aggregate(results$nestedness,
                          by = list(strain = results$strain, time = results$time),
                          FUN = mean),aggregate(results$nestedness,
                                                by = list(strain = results$strain, time = results$time),
                                                FUN = sd),aggregate(results$nestedness,
                                                                    by = list(strain = results$strain, time = results$time),
                                                                    FUN = length)
)[,c(1,2,3,6,9)]
myData$SE = myData$x.1/sqrt(myData$x.2)
colnames(myData) <- c("strain", "time", "mean", "sd", "n", "se")                 
limits <- aes(ymax = myData$mean + myData$se,
              ymin = myData$mean - myData$se)

p <- ggplot(data = myData, aes(x = factor(time), y = mean,
                               fill = factor(strain)))

p + geom_bar(stat = "identity",
             position = position_dodge(0.9)) +
  geom_errorbar(limits, position = position_dodge(0.9),
                width = 0.25) +
  labs(x = "Time Point", y = "Nestedness") +
  ggtitle("Nestedness by Strain and Time Point") +
  scale_fill_discrete(name = "Phage Strain") + ylim(0,1)  + theme_classic() + 
  theme(text = element_text(size=20))
model = aov(nestedness~strain*time, data=results)
summary(model)
t.test(nestedness~time, data= subset(results, results$strain=="14/1" & results$time>1))
model<- lmer(nestedness~time+strain+(1|replicate), data=results)


#testing difference in modularity between two phages across time
myData <- cbind(aggregate(results$modularity,
                          by = list(strain = results$strain, time = results$time),
                          FUN = mean),aggregate(results$modularity,
                                                by = list(strain = results$strain, time = results$time),
                                                FUN = sd),aggregate(results$modularity,
                                                                    by = list(strain = results$strain, time = results$time),
                                                                    FUN = length)
)[,c(1,2,3,6,9)]
myData$SE = myData$x.1/sqrt(myData$x.2)
colnames(myData) <- c("strain", "time", "mean", "sd", "n", "se")                 
limits <- aes(ymax = myData$mean + myData$se,
              ymin = myData$mean - myData$se)

p <- ggplot(data = myData, aes(x = factor(time), y = mean,
                               fill = factor(strain)))

p + geom_bar(stat = "identity",
             position = position_dodge(0.9)) +
  geom_errorbar(limits, position = position_dodge(0.9),
                width = 0.25) +
  labs(x = "Time Point", y = "Modularity") +
  ggtitle("Modularity by Strain and Time Point") +
  scale_fill_discrete(name = "Phage Strain") + ylim(0,1)  + theme_classic()+
  theme(text = element_text(size=20))
model = lm(modularity~strain*time, data=results)
summary(model)
TukeyHSD(model)

#using the other modularity from lpbrim package
myData <- cbind(aggregate(results$modd,
                          by = list(strain = results$strain, time = results$time),
                          FUN = mean),aggregate(results$modd,
                                                by = list(strain = results$strain, time = results$time),
                                                FUN = sd),aggregate(results$modd,
                                                                    by = list(strain = results$strain, time = results$time),
                                                                    FUN = length)
)[,c(1,2,3,6,9)]
myData$SE = myData$x.1/sqrt(myData$x.2)
colnames(myData) <- c("strain", "time", "mean", "sd", "n", "se")                 
limits <- aes(ymax = myData$mean + myData$se,
              ymin = myData$mean - myData$se)

p <- ggplot(data = myData, aes(x = factor(time), y = mean,
                               fill = factor(strain)))

p + geom_bar(stat = "identity",
             position = position_dodge(0.9)) +
  geom_errorbar(limits, position = position_dodge(0.9),
                width = 0.25) +
  labs(x = "Time Point", y = "Modularity") +
  ggtitle("Modularity by Strain and Time Point") +
  scale_fill_discrete(name = "Phage Strain") + ylim(0,1) + theme_classic() + 
  theme(text = element_text(size=20))


#nestedness and modularity for each phage seperately:
nestedness_14 <- data_summary(results[results$strain=="14",], varname="nestedness", 
                              groupnames="time")
nestedness_LU <- data_summary(results[results$strain=="LU",], varname="nestedness", 
                              groupnames="time")
modularity_14 <- data_summary(results[results$strain=="14",], varname="modularity", 
                              groupnames="time")
modularity_LU <- data_summary(results[results$strain=="LU",], varname="modularity", 
                              groupnames="time")

p<- ggplot(nestedness_14, aes(x=time, y=nestedness)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=nestedness-sd, ymax=nestedness+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="14/1 Nestedness vs. Time", x="Time Point", y = "Nestedness")+geom_smooth(method = "lm", se = FALSE)+ ylim(0.6,0.85)

p<- ggplot(nestedness_LU, aes(x=time, y=nestedness)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=nestedness-sd, ymax=nestedness+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="LUZ19 Nestedness vs. Time", x="Time Point", y = "Nestedness")+geom_smooth(method = "lm", se = FALSE) + ylim(0.6,0.85)

p<- ggplot(modularity_14, aes(x=time, y=modularity)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=modularity-sd, ymax=modularity+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="14/1 Modularity vs. Time", x="Time Point", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)+ ylim(0.05,0.23)

p<- ggplot(modularity_LU, aes(x=time, y=modularity)) + 
  geom_line() +
  geom_point()+
  geom_errorbar(aes(ymin=modularity-sd, ymax=modularity+sd), width=1,
                position=position_dodge(0.05))
p+labs(title="LUZ19 Modularity vs. Time", x="Time Point", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)+ ylim(0.05,0.23)




model= aov(nestedness~time*strain, data=results)
TukeyHSD(model)
model=aov(nestedness~time, data=results[results$strain=="14",])
summary(model)
TukeyHSD(model)
par(mfrow=c(2,2))
plot(model)

fit1 <- lm(nestedness~time, data = results[results$strain=="14",])
summary(fit1)
ggplotRegression(fit1) + ylim(0.6,0.85)

fit2<-lm(nestedness~time, data= nestedness_LU)
ggplotRegression(fit2)+ ylim(0.6,0.85)
fit3 = lm(modularity~time, data=modularity_14)
ggplotRegression(fit3)+ ylim(0.05,0.23)
fit4 = lm(modularity~time, data = modularity_LU)
ggplotRegression(fit4) + ylim(0.05,0.23)




par(mfrow=c(1,2)) 
plot(nestedness~time, data=results[results$strain=="14",], main="nestedness 14/1", xlab="time", pch= 15,col="darkgreen",cex=1.5)
reg1 <- lm(nestedness~time, data=results[results$strain=="14",])
abline(reg1)

plot(nestedness~time, data=results[results$strain=="LU",],main="nestedness LUZ19", xlab="time",pch=15, col = "red",cex=1.5)
reg2 <- lm(nestedness~time, data=results[results$strain=="LU",])
abline(reg2)


{#The correlation between nestedness and modularity
par(mfrow=c(1,2)) 
plot(nestedness ~ modularity, data=results[results$strain=="14",], main=" 14/1", xlab="modularity", pch= 19,col=c("blue","blue","blue","red","red","red","green","green","green") ,xlim=c(0,1), ylim=c(0,1),las=1)
model1<- lm(nestedness~modularity^2+time+connectance, data=results[results$strain=="14",])
summary(model1)
plot(nestedness ~ -modularity, data=results[results$strain=="LU",], main="LUZ19", xlab="modularity", pch= 19,col=c("blue","blue","blue","red","red","red","green","green","green") ,xlim=c(0,1), ylim=c(0,1),las=1)
legend(.6,.4, c("T1", "T5","T9"), fill = c("blue","red","green"))
model<- lm(nestedness~-modularity+time, data=results[results$strain=="LU",])
summary(model)
par(mfrow=c(2,2)) 
plot(model1)
plot(model)
par(mfrow=c(1,1)) 
}
#######CAlculating nestedness and modularity in random matrices
# calculate nestedness and modularity for the data:
matrix_dim <- 12
num_matrices <- 18
num_iterations <- 100

mod_result <- list()

nested_result <- list()

connectance_result <- list()

mod_result_2<- list()

for(index in 1:num_matrices) {
  
  mod_result[index] <- Q(matrices[[index]])
  
  nested_result[index] <- NODF(matrices[[index]])
  
  connectance_result[index] <- co_b(matrices[[index]])
  
  mod_result_2[index] <- modularity2 (matrices[[index]])
  
}

# calculate two metrics for a sample of random matrices:

mod_result_rnd <- matrix(nrow = num_iterations, ncol = num_matrices)

nested_result_rnd <- matrix(nrow = num_iterations, ncol = num_matrices)

connectance_result_rnd <- matrix(nrow = num_iterations, ncol = num_matrices)

for(ind in 1:num_matrices) for(iter in 1:num_iterations) {
  
  random_matrix <-  matrix(sample(as.matrix(matrices[[ind]])),ncol = ncol(matrices[[ind]]), nrow = nrow(matrices[[ind]]))
  nested_result_rnd[iter, ind] <- NODF(random_matrix)
  connectance_result_rnd[iter,ind] <-co_b(random_matrix)
  
}

for(ind in 1:num_matrices) for(iter in 1:num_iterations) {
  
  random_matrix <-   matrix(sample(matrices[[ind]]), ncol = ncol(matrices[[ind]]), nrow = nrow(matrices[[ind]]))
  
  mod_result_rnd[iter, ind] <- modularity2(random_matrix)
  
}

#export the results
write.table(mod_result_rnd,
            "randommodularity.csv",
            sep=",",
            col.names=T,
            quote=F,
            row.names=F)

write.table(nested_result_rnd,
            "random_nestedness.csv",
            sep=",",
            col.names=T,
            quote=F,
            row.names=F)

number_of_plots <- 5
number_matrices_inplot <-3
# plot the metrics for the data (solid discs) and plot the metrics for the random matrices (open circles):

for(index in 0:number_of_plots)  {
  
  plot(mod_result[(3*index) +1], nested_result[(3*index) +1], col= "red",xlim = c(0,1)
       ,ylim=c(0,1), pch=20, main= names(matrices)[[(3*index) +1]])
  for (g in 1:number_matrices_inplot){
    points(mod_result[(3*index) +g], nested_result[(3*index) +g], col=g+1 ,xlim = c(0,1),ylim=c(0,1), pch=20)
    points(mod_result_rnd[,((3*index) +g)], 
           nested_result_rnd[,((3*index) +g)],col=adjustcolor(g+1, alpha=0.05),pch=20)
  }
}




#Binding nested data with random nestedness to run tests
nested_result_rnd <- read.csv("~/Desktop/New-matrix/bri/random_nestedness.csv")
nestedresult2<-nested_result
nestedresultrandom<-nested_result_rnd
nestedresult2 <- as.data.frame(nestedresult2)
nestedresultrandom <- as.data.frame(nestedresultrandom)
nestedresult2$randomness = "real"
nestedresultrandom$randomness = "random"
nestedresult2 <- as.data.frame(nestedresult2,nrow=1,ncol=19)
colnames(nestedresult2)= colnames(nestedresultrandom)
nested_data_and_random<- rbind(nestedresult2, nestedresultrandom)
View(nested_data_and_random)
names=list()
names= c(results$.id, "randomness")
colnames(nested_data_and_random)= names
View(nested_data_and_random)
write.table(nested_data_and_random,
            "newrandomnestedness.csv",
            sep=",",
            col.names=T,
            quote=F,
            row.names=F)

#Binding modularity data with random modularity to run tests

mod_result_rnd <- read.csv("~/Desktop/New-matrix/bri/randommodularity.csv")
modresult2<-mod_result
modresultrandom<-mod_result_rnd
modresult2<- as.data.frame(modresult2)
modresultrandom<- as.data.frame(modresultrandom)
modresult2$randomness = "real"
modresultrandom$randomness = "random"
modresult2 <- as.data.frame(modresult2,nrow=1,ncol=19)
colnames(modresult2)= colnames(modresultrandom)
mod_data_and_random<- rbind(modresult2, modresultrandom)
names=list()
names= c(results$.id, "randomness")
colnames(mod_data_and_random)= names
names= c(results$.id, "randomness")
names(mod_data_and_random)= names
View(mod_data_and_random)
write.table(mod_data_and_random,
            "newrandommodularity.csv",
            sep=",",
            col.names=T,
            quote=F,
            row.names=F)
###Plotting nestedness
l <- reshape(nested_data_and_random, 
             varying = as.character(results$.id), 
             v.names = "nestedness",
             timevar = "matrix", 
             times = as.character(results$.id), 
             direction = "long")
View(l)
l <- data_summary(l, varname="nestedness", 
                  groupnames=c("randomness","matrix"))

p<- ggplot(subset(l, l$randomness=="random" )[c(1:3,7:9,13:15),], aes(x=matrix, y=nestedness)) + 
  geom_line() +
  geom_point(mapping = aes(x=matrix,y=nestedness), 
             data = subset(l, l$randomness=="real" )[c(1:3,7:9,13:15),],col="red" , lwd=5)+
  geom_errorbar(aes(ymin=min, ymax=max), width=0.3,
                position=position_dodge(0.05))
p+labs(title="14/1", x="Matrix", y = "Nestedness")+geom_smooth(method = "lm", se = FALSE)+
  theme(text = element_text(size=20))
p<- ggplot(l[l$randomness=="random",][c(4:6,10:12,16:18),], aes(x=matrix, y=nestedness)) + 
  geom_line() +
  geom_point(mapping = aes(x=matrix,y=nestedness), data = l[l$randomness=="real",][c(4:6,10:12,16:18),],col="red" , lwd=5)+
  geom_errorbar(aes(ymin=min, ymax=max), width=0.3,
                position=position_dodge(0.05))
p+labs(title="LUZ19", x="Matrix", y = "Nestedness")+geom_smooth(method = "lm", se = FALSE)+
  theme(text = element_text(size=20))

###Plotting modularity
l <- reshape(mod_data_and_random, 
             varying = as.character(results$.id), 
             v.names = "modularity",
             timevar = "matrix", 
             times = as.character(results$.id), 
             direction = "long")
View(l)
l <- data_summary(l, varname="modularity", 
                  groupnames=c("randomness","matrix"))

p<- ggplot(subset(l, l$randomness=="random" )[c(1:3,7:9,13:15),], aes(x=matrix, y=modularity)) + 
  geom_line() +
  geom_point(mapping = aes(x=matrix,y=modularity), 
             data = subset(l, l$randomness=="real" )[c(1:3,7:9,13:15),],col="red" , lwd=5)+
  geom_errorbar(aes(ymin=min, ymax=max), width=0.3,
                position=position_dodge(0.05))
p+labs(title="14/1", x="Matrix", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)+
  theme(text = element_text(size=20))
p<- ggplot(l[l$randomness=="random",][c(4:6,10:12,16:18),], aes(x=matrix, y=modularity)) + 
  geom_line() +
  geom_point(mapping = aes(x=matrix,y=modularity), data = l[l$randomness=="real",][c(4:6,10:12,16:18),],col="red" , lwd=5)+
  geom_errorbar(aes(ymin=min, ymax=max), width=0.3,
                position=position_dodge(0.05))
p+labs(title="LUZ19", x="Matrix", y = "Modularity")+geom_smooth(method = "lm", se = FALSE)+
  theme(text = element_text(size=20))


#PCA
ir.pca <- prcomp(results[,c(3,6:8)],
                 center = TRUE,
                 scale. = TRUE) 
print(ir.pca)
# plot method
par(mfrow=c(1,2)) 
plot(ir.pca, type = "l")
summary(ir.pca)
biplot(ir.pca)
PCbiplot <- function(PC, x="PC1", y="PC2") {
  # PC being a prcomp object
  data <- data.frame(obsnames=row.names(PC$x), PC$x)
  plot <- ggplot(data, aes_string(x=x, y=y)) + geom_text(alpha=.4, size=3, aes(label=obsnames))
  plot <- plot + geom_hline(aes(0), size=.2) + geom_vline(aes(0), size=.2)
  datapc <- data.frame(varnames=rownames(PC$rotation), PC$rotation)
  mult <- min(
    (max(data[,y]) - min(data[,y])/(max(datapc[,y])-min(datapc[,y]))),
    (max(data[,x]) - min(data[,x])/(max(datapc[,x])-min(datapc[,x])))
  )
  datapc <- transform(datapc,
                      v1 = .7 * mult * (get(x)),
                      v2 = .7 * mult * (get(y))
  )
  plot <- plot + coord_equal() + geom_text(data=datapc, aes(x=v1, y=v2, label=varnames), size = 5, vjust=1, color="red")
  plot <- plot + geom_segment(data=datapc, aes(x=0, y=0, xend=v1, yend=v2), arrow=arrow(length=unit(0.2,"cm")), alpha=0.75, color="red")
  plot
}
PCbiplot(ir.pca)

#Studying the correlation between imapct and host range
generalist <- read.csv("C:/Users/Lafi Aldakak/OneDrive/M2 Project/Data/generlist v specialistR.csv")
generalist <- generalist[generalist[,5]>0,]
generalist$lnMean_Impact=log(generalist$Mean_Impact)
generalist$Strain= as.factor(generalist$Strain)
generalist$Time= as.numeric(generalist$Time)





generalist_Impact <- data_summary(generalist, varname="Mean_Impact", 
                                  groupnames=c("Time", "Strain"))
generalist_Range <- data_summary(generalist, varname="Range", 
                                 groupnames=c("Time", "Strain"))
# Impact by time
limits <- aes(ymax = generalist_Impact$Mean_Impact + generalist_Impact$se,
              ymin = generalist_Impact$Mean_Impact - generalist_Impact$se)
p <- ggplot(data = generalist_Impact, aes(x=Time, y=Mean_Impact,
                                          fill = factor(Strain)))

p + geom_bar(stat = "identity",
             position = position_dodge(0.9)) +
  geom_errorbar(limits, position = position_dodge(0.9),
                width = 0.25) +
  labs(x = "Time Point", y = "Mean Impact") +
  ggtitle("Mean Phage Impact by Time") +
  scale_fill_discrete(name = "Phage Strain")  + theme_classic() + 
  theme(text = element_text(size=20))
model=aov(Mean_Impact~Time*Strain, data=generalist)
summary(model)


#Range by time
limits <- aes(ymax = generalist_Range$Range + generalist_Range$se,
              ymin = generalist_Range$Range - generalist_Range$se)
p <- ggplot(data = generalist_Range, aes(x=Time, y=Range,
                                         fill = factor(Strain)))

p + geom_bar(stat = "identity",
             position = position_dodge(0.9)) +
  geom_errorbar(limits, position = position_dodge(0.9),
                width = 0.25) +
  labs(x = "Time Point", y = "Mean Host Range of Phage") +
  ggtitle("Mean Host Range by Time") +
  scale_fill_discrete(name = "Phage Strain")  + theme_classic() + 
  theme(text = element_text(size=20))

model=aov(Range~Time*Strain, data=generalist)
summary(model)
TukeyHSD(model)
par(mfrow=c(2,2))
plot(model)

#Impact and range
attach(generalist)
#total
f <- ggplot(data= generalist, aes(x= Range, y= Mean_Impact ))
f + geom_point(position = "jitter") + geom_smooth(method = "lm", formula = y ~  I(x^2), size = 1) +
  labs(x = "Host Range", y = "Mean Impact") +
  ggtitle("The relationship between mean impact and host range") +
  scale_fill_discrete(name = "Time Point") +ylim(0,0.6) + theme_classic() + 
  theme(text = element_text(size=20))
model=lm(formula = Mean_Impact ~  Range^2 +Strain, data=generalist)
summary(model)
model2=lm(formula = Mean_Impact ~  I(Range^2)*Strain, data=generalist)
summary(model2)
anova(model,model2)
par(mfrow=c(2,2))
plot(model2)

#In 14/1
f <- ggplot(data= generalist[generalist$Strain=="14/1",], aes(x= Range, y= Mean_Impact, fill= factor(Time) ))
f + geom_point(position = "jitter", col=factor(Time)) + geom_smooth(method='lm') +
  labs(x = "Host Range", y = "Mean Impact") +
  ggtitle("14/1") +
  scale_fill_discrete(name = "Time Point") +ylim(0,0.6) + theme_classic() + 
  theme(text = element_text(size=20))
#In LUZ19
f <- ggplot(data= generalist[generalist$Strain=="LUZ19",], aes(x= Range, y= Mean_Impact, fill= factor(Time) ))
f + geom_point(position = "jitter") + geom_smooth(method='lm') +
  labs(x = "Host Range", y = "Mean Impact") +
  ggtitle("LUZ19") +
  scale_fill_discrete(name = "Time Point") +ylim(0,0.6) + theme_classic() + 
  theme(text = element_text(size=20))
model=lm(Mean_Impact~Range,data=subset(generalist, Strain == "LUZ19" & Time == "5"))
summary(model)
summary(model)$coefficients[2,4]


##fitting aa linear model of impact:
#check data distribution
require(car)
require(MASS)
library(car)
library(MASS)
library(lme4)
lmm <- lmer(Mean_Impact ~ Range + Time +Strain + (1 | Population/Phage_Isolate), data = generalist, REML = FALSE)
summary(lmm)



par(mfrow=c(1,1))
plot(lnMean_Impact ~ Range, data=generalist, main=" Average Impact vs Range", xlab="Number of affected bacteria",ylab = "impact/num of affected bacteria", pch= 19,col=c("blue") )
plot(SumImp ~ sigNum, data=generalist, main=" Total Impact vs Range", xlab="Number of affected bacteria",ylab = "Sum of impact on all affected bacteria", pch= 19,col=c("blue"))
model<- lm(SumImp~ sigNum , data= generalist)
summary(model)
abline(model)
par(mfrow=c(2,2))
plot(model)

#pca for host range
ir.pca <- prcomp(generalist[c(1,5:7)],
                 center = TRUE,
                 scale. = TRUE) 
print(ir.pca)
# plot method
par(mfrow=c(1,2)) 
plot(ir.pca, type = "l")
summary(ir.pca)
biplot(ir.pca)

# Correlation between range and time
par(mfrow=c(1,2))
plot(Imp.Num ~ sigNum, data=generalist, main=" Average Impact vs. Range", xlab="Number of susceptible host isolates",ylab = "Average impact of phage (total impact/susceptible isolates", pch= 19,col=c("blue") )
model1<- lm(Imp.Num~ sigNum , data= generalist)
summary(model1)
abline(model1)
plot(SumImp~sigNum, data=generalist, main=" Total Impact vs. Range", xlab="Number of susceptible host isolates",ylab = "Total impact of phage", pch= 19,col=c("pink") )
model<- lm(SumImp~ sigNum , data= generalist)
summary(model)
abline(model)
par(mfrow=c(2,2))
plot(model)
plot(model1)
#doing the same analysis for each phage seperately
#14/1
par(mfrow=c(1,2))
#plot(Imp.Num ~ sigNum, data=generalist[c(1:108),], main=" Average Impact vs. Range 14/1", xlab="Number of susceptible host isolates",ylab = "Average impact of phage (total impact/susceptible isolates", pch= 19,col=c("green") )
model1<- lm(Imp.Num~ sigNum , data= generalist[c(1:108),])
summary(model1)
abline(model1)
plot(SumImp~sigNum, data=generalist[c(1:108),], main=" Total Impact vs. Range 14/1", xlab="Number of susceptible host isolates",ylab = "Total impact of phage", pch= 19,col=c("green") )
model<- lm(SumImp~ sigNum , data= generalist[c(1:108),])
summary(model)
abline(model)
par(mfrow=c(2,2))
plot(model)
plot(model1)
# LUZ19
par(mfrow=c(1,2))
#plot(Imp.Num ~ sigNum, data=generalist[c(109:215),], main=" Average Impact vs. Range LUZ19", xlab="Number of susceptible host isolates",ylab = "Average impact of phage (total impact/susceptible isolates", pch= 19,col=c("red") )
model1<- lm(Imp.Num~ sigNum ,data= generalist[c(109:215),])
summary(model1)
abline(model1)
plot(SumImp~sigNum, data=generalist[c(109:215),], main=" Total Impact vs. Range LUZ19", xlab="Number of susceptible host isolates",ylab = "Total impact of phage", pch= 19,col=c("red") )
model<- lm(SumImp~ sigNum , data= generalist[c(109:215),])
summary(model)
abline(model)
par(mfrow=c(2,2))
plot(model)
plot(model1)

#testing the same model but removing outliers
#par(mfrow=c(1,1))
#plot(SumImp ~ sigNum, data=generalist[-c(24,160),], main=" Total Impact vs Range", xlab="Number of affected bacteria",ylab = "Sum of impact on all affected bacteria", pch= 19,col=c("blue") )
#model<- lm(SumImp~ sigNum , data= generalist[-c(24,160),])
#summary(model)
#abline(model)
#par(mfrow=c(2,2))
#plot(model)


#test range difference between the two phages


t.test(generalist$Range~generalist$Strain)

# create value labels 
strain.f <- factor(generalist$Strain, levels= c("14/1", "LUZ19"),
                   labels = c("14/1", "LUZ19")) 

# plot densities 
par(mfrow=c(1,1),mar=c(2,2,2,2))
sm.density.compare(generalist$Range, generalist$Strain, xlab="Range of phage")
title(main="Density distribution of range in 14/1 and LUZ19")

# add legend via mouse click
colfill<-c(2:(2+length(levels(strain.f)))) 
legend(locator(1), levels(strain.f), fill=colfill)
